Index: mandoline/ui/phone_ui/phone_browser_application_delegate.cc |
diff --git a/mandoline/ui/phone_ui/phone_browser_application_delegate.cc b/mandoline/ui/phone_ui/phone_browser_application_delegate.cc |
index db21dde16febbd830c3b7eaa27684eb622dec49f..93307aad9d51f0956e7db6bd9e79a584bb9fedbc 100644 |
--- a/mandoline/ui/phone_ui/phone_browser_application_delegate.cc |
+++ b/mandoline/ui/phone_ui/phone_browser_application_delegate.cc |
@@ -47,7 +47,7 @@ |
break; |
} |
} |
- mus::CreateSingleViewTreeHost(app_, this, &host_); |
+ mojo::CreateSingleViewTreeHost(app_, this, &host_); |
} |
bool PhoneBrowserApplicationDelegate::ConfigureIncomingConnection( |
@@ -66,9 +66,9 @@ |
} |
//////////////////////////////////////////////////////////////////////////////// |
-// PhoneBrowserApplicationDelegate, mus::ViewTreeDelegate implementation: |
+// PhoneBrowserApplicationDelegate, mojo::ViewTreeDelegate implementation: |
-void PhoneBrowserApplicationDelegate::OnEmbed(mus::View* root) { |
+void PhoneBrowserApplicationDelegate::OnEmbed(mojo::View* root) { |
CHECK(!root_); |
root_ = root; |
content_ = root->connection()->CreateView(); |
@@ -83,13 +83,14 @@ |
} |
void PhoneBrowserApplicationDelegate::OnConnectionLost( |
- mus::ViewTreeConnection* connection) {} |
+ mojo::ViewTreeConnection* connection) { |
+} |
//////////////////////////////////////////////////////////////////////////////// |
// PhoneBrowserApplicationDelegate, mus::ViewObserver implementation: |
void PhoneBrowserApplicationDelegate::OnViewBoundsChanged( |
- mus::View* view, |
+ mojo::View* view, |
const mojo::Rect& old_bounds, |
const mojo::Rect& new_bounds) { |
CHECK_EQ(view, root_); |
@@ -83,13 +83,14 @@ |
//////////////////////////////////////////////////////////////////////////////// |
-// PhoneBrowserApplicationDelegate, mus::ViewObserver implementation: |
+// PhoneBrowserApplicationDelegate, mojo::ViewObserver implementation: |
void PhoneBrowserApplicationDelegate::OnViewBoundsChanged( |